summary refs log tree commit diff
diff options
context:
space:
mode:
authorSamuel Ortiz <samuel@sortiz.org>2008-12-17 15:44:58 -0800
committerDavid S. Miller <davem@davemloft.net>2008-12-17 15:44:58 -0800
commit69c30e1e7492192f882a3fc11888b320fde5206a (patch)
tree6181c8b6f516c2274d78983062b4da821fa71ffb
parent2fccd2814f8ebc8f1bd325dc46e11c333fc76ab3 (diff)
downloadlinux-69c30e1e7492192f882a3fc11888b320fde5206a.tar.gz
irda: Add irda_skb_cb qdisc related padding
We need to pad irda_skb_cb in order to keep it safe accross dev_queue_xmit()
calls. This is some ugly and temporary hack triggered by recent qisc code
changes.
Even though it fixes bugzilla.kernel.org bug #11795, it will be replaced by a
proper fix before 2.6.29 is released.

Signed-off-by: Samuel Ortiz <samuel@sortiz.org>
Signed-off-by: David S. Miller <davem@davemloft.net>
-rw-r--r--include/net/irda/irda_device.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/include/net/irda/irda_device.h b/include/net/irda/irda_device.h
index 3025ae17ddbe..94c852d47d0f 100644
--- a/include/net/irda/irda_device.h
+++ b/include/net/irda/irda_device.h
@@ -135,9 +135,11 @@ struct dongle_reg {
 
 /* 
  * Per-packet information we need to hide inside sk_buff 
  * (must not exceed 48 bytes, check with struct sk_buff) 
  */
 struct irda_skb_cb {
+	unsigned int default_qdisc_pad;
 	magic_t magic;       /* Be sure that we can trust the information */
 	__u32   next_speed;  /* The Speed to be set *after* this frame */
 	__u16   mtt;         /* Minimum turn around time */
@@ -135,9 +135,11 @@ struct dongle_reg {
 /* 
  * Per-packet information we need to hide inside sk_buff 
- * (must not exceed 48 bytes, check with struct sk_buff) 
+ * (must not exceed 48 bytes, check with struct sk_buff)
+ * The default_qdisc_pad field is a temporary hack.
  */
 struct irda_skb_cb {